summary refs log tree commit diff
path: root/pkgs/applications/editors
diff options
context:
space:
mode:
authorMarc Weber <marco-oweber@gmx.de>2010-02-18 01:49:22 +0000
committerMarc Weber <marco-oweber@gmx.de>2010-02-18 01:49:22 +0000
commit4007d197004abf1abdf31cf0c001e33a287e94cb (patch)
treef172a028d6b697b8d56824bc7e258c74aca9c7f5 /pkgs/applications/editors
parent6a48baead341a76ae1a3ae173d53d3f0a2f61081 (diff)
downloadnixpkgs-4007d197004abf1abdf31cf0c001e33a287e94cb.tar
nixpkgs-4007d197004abf1abdf31cf0c001e33a287e94cb.tar.gz
nixpkgs-4007d197004abf1abdf31cf0c001e33a287e94cb.tar.bz2
nixpkgs-4007d197004abf1abdf31cf0c001e33a287e94cb.tar.lz
nixpkgs-4007d197004abf1abdf31cf0c001e33a287e94cb.tar.xz
nixpkgs-4007d197004abf1abdf31cf0c001e33a287e94cb.tar.zst
nixpkgs-4007d197004abf1abdf31cf0c001e33a287e94cb.zip
fix vim_configurable
svn path=/nixpkgs/trunk/; revision=20084
Diffstat (limited to 'pkgs/applications/editors')
-rw-r--r--pkgs/applications/editors/vim/configurable.nix16
1 files changed, 8 insertions, 8 deletions
diff --git a/pkgs/applications/editors/vim/configurable.nix b/pkgs/applications/editors/vim/configurable.nix
index 162b0c92ebe..bb51d23790b 100644
--- a/pkgs/applications/editors/vim/configurable.nix
+++ b/pkgs/applications/editors/vim/configurable.nix
@@ -13,7 +13,7 @@ composableDerivation {} {
 
     configureFlags = ["--enable-gui=auto" "--with-features=${args.features}"];
 
-    buildInputs = [ncurses pkgconfig]
+    buildNativeInputs = [ncurses pkgconfig]
       ++ [ gtk libX11 libXext libSM libXpm libXt libXaw libXau libXmu ];
 
     # most interpreters aren't tested yet.. (see python for example how to do it)
@@ -26,17 +26,17 @@ composableDerivation {} {
       // edf { name = "xsmp"; } #Disable XSMP session management
       // edf { name = "xsmp_interact"; } #Disable XSMP interaction
       // edf { name = "mzscheme"; } #Include MzScheme interpreter.
       // edf { name = "perl"; feat = "perlinterp"; enable = { buildInputs = [perl]; };} #Include Perl interpreter.
       // edf { name = "python"; feat = "pythoninterp"; enable = { buildInputs = [python]; }; } #Include Python interpreter.
       // edf { name = "tcl"; enable = { buildInputs = [tcl]; }; } #Include Tcl interpreter.
       // edf { name = "ruby"; feat = "rubyinterp"; enable = { buildInputs = [ruby]; };} #Include Ruby interpreter.
       // edf { name = "cscope"; } #Include cscope interface.
       // edf { name = "workshop"; } #Include Sun Visual Workshop support.
       // edf { name = "netbeans"; } #Disable NetBeans integration support.
       // edf { name = "sniff"; } #Include Sniff interface.
       // edf { name = "multibyte"; } #Include multibyte editing support.
       // edf { name = "hangulinput"; } #Include Hangul input support.
       # // edf { name = "xim"; enable = { buildInputs = [xim]; }; } #Include XIM input support.
       // edf { name = "fontset"; } #Include X fontset output support.
       // edf { name = "acl"; } #Don't check for ACL support.
       // edf { name = "gpm"; } #Don't use gpm (Linux mouse daemon).
@@ -62,11 +62,11 @@ composableDerivation {} {
 
   postInstall = "
     rpath=`patchelf --print-rpath \$out/bin/vim`;
-    for i in $\buildInputs; do
+    for i in $\buildNativeInputs; do
       echo adding \$i/lib
       rpath=\$rpath:\$i/lib
     done
-    echo \$buildInputs
+    echo \$buildNativeInputs
     echo \$rpath
     patchelf --set-rpath \$rpath \$out/bin/{vim,gvim}
   ";
@@ -26,17 +26,17 @@ composableDerivation {} {
       // edf { name = "xsmp_interact"; } #Disable XSMP interaction
       // edf { name = "mzscheme"; } #Include MzScheme interpreter.
-      // edf { name = "perl"; feat = "perlinterp"; enable = { buildInputs = [perl]; };} #Include Perl interpreter.
-      // edf { name = "python"; feat = "pythoninterp"; enable = { buildInputs = [python]; }; } #Include Python interpreter.
-      // edf { name = "tcl"; enable = { buildInputs = [tcl]; }; } #Include Tcl interpreter.
-      // edf { name = "ruby"; feat = "rubyinterp"; enable = { buildInputs = [ruby]; };} #Include Ruby interpreter.
+      // edf { name = "perl"; feat = "perlinterp"; enable = { buildNativeInputs = [perl]; };} #Include Perl interpreter.
+      // edf { name = "python"; feat = "pythoninterp"; enable = { buildNativeInputs = [python]; }; } #Include Python interpreter.
+      // edf { name = "tcl"; enable = { buildNativeInputs = [tcl]; }; } #Include Tcl interpreter.
+      // edf { name = "ruby"; feat = "rubyinterp"; enable = { buildNativeInputs = [ruby]; };} #Include Ruby interpreter.
       // edf { name = "cscope"; } #Include cscope interface.
       // edf { name = "workshop"; } #Include Sun Visual Workshop support.
@@ -26,17 +26,17 @@ composableDerivation {} {
       // edf { name = "multibyte"; } #Include multibyte editing support.
       // edf { name = "hangulinput"; } #Include Hangul input support.
-      # // edf { name = "xim"; enable = { buildInputs = [xim]; }; } #Include XIM input support.
+      # // edf { name = "xim"; enable = { buildNativeInputs = [xim]; }; } #Include XIM input support.
       // edf { name = "fontset"; } #Include X fontset output support.
       // edf { name = "acl"; } #Don't check for ACL support.